import colorama
import pyfiglet
from colorama import Fore as colour
import itertools
import threading
import time as Time
import sys

# color variables because of course colorama's color names have to be in caps
red = colour.RED
blue = colour.CYAN
black = colour.BLACK
green = colour.GREEN
white = colour.WHITE
magenta = colour.MAGENTA
reset_color = colour.RESET
DEFAULT_FONT = 'standard'

def prompt(color = reset_color, text = "press enter to continue"):
    """creates a no-input continue prompt."""
    value = input(color + f"{text} ")
    if value == "":
        return
    else:
        print("No input required!")
        prompt(text)

def banner(color = reset_color, *, text, font=DEFAULT_FONT):
    """creates a banner for your application"""
    banner = pyfiglet.figlet_format(text, font)
    print(color + banner)
    print(white)

def color_print(color, text):
    """makes colored text"""
    print(color + text + white)

def loading_bar(color=reset_color, text="loading...", time=1):
    """makes a little loading icon next to your inputed text, for however long you'd like it to wait."""
    done = False
    def animate():
        for c in itertools.cycle(['|', '/', '-', '\\']):
            if done:
                break
            sys.stdout.write(color + f'\r{text} ' + c)
            sys.stdout.flush()
            Time.sleep(0.1)
        sys.stdout.write(color + '\rDone!')

    t = threading.Thread(target=animate)
    t.daemon=True   # allows program to be stopped upon KeyboardInterrupt
    t.start()
    Time.sleep(int(time))
    done = True
    print(reset_color + "\ndone")

# maybe important?
colorama.init()


from info import *
from copperhead import *
from sys import argv as arg
from colorama import Fore, Back

def list():
    prompt(color=red, text="this command lists *all* fonts usable with the banner function. the list is very long.\n\n press enter to continue...")
    print("\n".join(fonts))

def help():
    print(f"""
    CLI:
        -f -> shows all font options for banner()
        help -> displays this message
    Functions and values
        all text based functions share at least 2 common args;
            text: this one is pretty obvious. there is not a default value for this on any function besides prompt.
            color: this is defaulted to whatever color your CLI interface is. 
        
        color options:
            red,
            blue,
            black,
            green,
            white (more of an off gray),
            magenta.
        
        banner documentation:
            banner has the standard options first, and then font. font options can be found by running {Back.CYAN}python3 -m copperhead -f {Back.RESET}
    """)
    prompt()

if arg[1] == "-f":
    list()
elif arg[1] == "-h":
    help()